using System;
using Xamarin.Forms;
using Xamarin.Forms.Platform.iOS;

#if __UNIFIED__
using Foundation;
using UIKit;
using CoreGraphics;
#else
using nint = System.Int32;
using nuint = System.Int32;
using nfloat = System.Single;

using MonoTouch.Foundation;
using MonoTouch.UIKit;

using CGRect = System.Drawing.RectangleF;
using CGPoint = System.Drawing.PointF;
using CGSize = System.Drawing.SizeF;
#endif

namespace Syncfusion.SfSchedule.XForms.iOS
{
	public static class ScheduleHelper
    {
        #region Date Converters
        public static NSDate DateTimeToNSDate(this DateTime date)
		{
			if (date.Kind == DateTimeKind.Unspecified)
				date = DateTime.SpecifyKind (date, DateTimeKind.Local);
			return (NSDate) date;
		}

		public static DateTime NSDateToDateTime(this NSDate nsDate) {
			if (nsDate == null) {
				return new DateTime();
			} else {
				DateTime reference = TimeZone.CurrentTimeZone.ToLocalTime (new DateTime (2001, 1, 1, 0, 0, 0));
				return (DateTime)reference.AddSeconds (nsDate.SecondsSinceReferenceDate);
			}
		}

        #endregion

        #region Color Converter

		public static UIColor ColorToUIColor(Xamarin.Forms.Color color) {
			UIColor nativeColor  = UIColor.FromRGBA ((float)color.R, (float)color.G, (float)color.B,(float)color.A);
			return nativeColor;
        }

		internal static UIColor NonworkingHourNativeColorToUIColor(Xamarin.Forms.Color color)
		{
			UIColor nativeColor = UIColor.FromRGBA((float)color.R, (float)color.G, (float)color.B, (float)0.3);
			return nativeColor;
		}

        #endregion


		#region UIFontConverter

		public static UIFont GetNativeFont(Font font)
		{
			UIFont Font;

			if (font.FontFamily == null)
				Font = UIFont.SystemFontOfSize((float)font.FontSize);
			else
				Font = UIFont.FromName(font.FontFamily
					, (float)font.FontSize);

			if (font.FontAttributes == FontAttributes.Bold)
			{
				Font = UIFont.FromDescriptor(Font.FontDescriptor.CreateWithTraits(UIFontDescriptorSymbolicTraits.Bold), 0);
			}
			else if (font.FontAttributes == FontAttributes.Italic)
			{
				Font = UIFont.FromDescriptor(Font.FontDescriptor.CreateWithTraits(UIFontDescriptorSymbolicTraits.Italic), 0);
			}
			else 
			{
				Font = UIFont.FromDescriptor(Font.FontDescriptor.CreateWithTraits(UIFontDescriptorSymbolicTraits.ClassTransitionalSerifs), 0);
			}

			return Font;
		}
		#endregion


		#region UIFontSize

		public static UIFont GetNativeFontSize(double fontSize)
		{
			UIFont Font;
			Font = UIFont.SystemFontOfSize((float)fontSize);

			return Font;
		}
		#endregion

		public static Color UIColorToColor(UIColor color)
		{
			nfloat a, b, c, d;
			color.GetRGBA(out a, out b, out c, out d);
			Color nativeColor = Color.FromRgba(a, b, c, d);
			return nativeColor;
		}

		#region ConvertFormsToNativeViews

		public static UIView ConvertFormsToNative(Xamarin.Forms.View view, CGRect size)
		{

			var renderer = RendererFactory.GetRenderer(view);

			renderer.NativeView.Frame = size;

			renderer.NativeView.AutoresizingMask = UIViewAutoresizing.All;
			renderer.NativeView.ContentMode = UIViewContentMode.ScaleToFill;

			renderer.Element.Layout(size.ToRectangle());

			var nativeView = renderer.NativeView;

			nativeView.SetNeedsLayout();

			return nativeView;
		}

		public static UIView ConvertFormsToNative(Xamarin.Forms.View view)
		{

			var renderer = RendererFactory.GetRenderer(view);

			//renderer.NativeView.Frame = size;

			renderer.NativeView.AutoresizingMask = UIViewAutoresizing.All;
			renderer.NativeView.ContentMode = UIViewContentMode.ScaleToFill;

			//renderer.Element.Layout(size.ToRectangle());

			var nativeView = renderer.NativeView;

			nativeView.SetNeedsLayout();

			return nativeView;
		}
		#endregion
	}
}

